/************************************************************************
 *
 *  tch_user.c 
 *  Terascan extraction  User Interface Module
 *  
 *  This file handles collecting information from the user and displaying
 *  information to the user.  This C module is part of the code used to
 *  generate tchannel.exe.
 *  
 *  ADM   29 MAR 1993
 *
 ************************************************************************/

/******* compiler #includes *******/
#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>


/******* program #includes *******/
#include "tch_defs.h"

/******* local global data *******/
extern char
    buf[BUF_SIZE];

  /*
   *
   */
char
     *month_name(/* int n */);


/************************************************************************
 *
 *   function tdf_infilename() - asks user to enter input file name
 *
 ************************************************************************/
int
tdf_infilename(input_filename)
char *input_filename;
{
  char *cc;

  printf("\nEnter image filename or quit: ");
  if ((cc = gets(input_filename)) == NULL){
      printf(GETS_ERROR);
      exit(0);
  } /* end if cc */
  if ((strncmp(input_filename,"quit",4)) == 0) return(RC_QUIT);
  if ((strncmp(input_filename,"QUIT",4)) == 0) return(RC_QUIT);

  return(RC_GOOD);
} /* end of tdf_infilename() */

/************************************************************************
 *
 *   function tdf_outfilename()  - asks user to enter name of output
 *        file.
 *
 ************************************************************************/
int
tdf_outfilename(output_filename, channel_num)
char *output_filename;
int channel_num;
{
  char *cc, ext[4];
  char newname[FNAME_SIZE];

  bzero(newname, sizeof(newname));

  ext[0]='c';
  ext[1]='h';
  ext[2]=0x30 + channel_num;  /* make it an ASCII character */
  ext[3]=0;

  strcpy(output_filename,ext);

  printf("\nPress RETURN to set output filename to %s, or", output_filename);
  printf("\n   enter output filename, or quit: ");

  if ((cc = gets(newname)) == NULL){
      printf(GETS_ERROR);
      exit(0);
  } /* end if cc */

  if ((strncmp(newname,"quit",4)) == 0) return(RC_QUIT);
  if ((strncmp(newname,"QUIT",4)) == 0) return(RC_QUIT);
  if (newname[0] != 0) strcpy(output_filename, newname);
  return(RC_GOOD);
} /* end of tdf_outfilename() */


/************************************************************************
 *
 *   function figure_out() - determines dimensions of channel data
 *
 ************************************************************************/
int
figure_out(input_filename, line_size, sample_size, pixel_size)
char *input_filename;
int *line_size, *sample_size, *pixel_size;
{
   char *cc, *nn;
   int n;

   /* if filename contains I001, I002, I003, I007 then NOAA */
   /* if filename contains I004, I005, I006 then DMSP */
   /* else ask user to stuff info */

   printf("Is this a KuDA GAC file? (y/n): ");
   if ((cc = gets(buf)) == NULL){
       printf(GETS_ERROR);
       exit(0);
   } /* end if cc */
   switch (buf[0]) {
     case 'Y':
     case 'y':
        printf("line size=641  sample size=441   pixel size=2\n");
        *line_size=641;
        *sample_size=441;
        *pixel_size=2;
        return (RC_GOOD);
        break;
     default:
        break;
   }
   /* NOAA:  line_size=1200  sample_size=1200  pixel_size=2 */
   if ((nn=strstr(input_filename, "I001")) != NULL) {
       *line_size=*sample_size=1200;
       *pixel_size=2;
   }
   else if ((nn=strstr(input_filename, "I002")) != NULL) {
       *line_size=*sample_size=1200;
       *pixel_size=2;
   }
   else if ((nn=strstr(input_filename, "I003")) != NULL) {
       *line_size=*sample_size=1200;
       *pixel_size=2;
   }
   else if ((nn=strstr(input_filename, "I007")) != NULL) {
       *line_size=*sample_size=1200;
       *pixel_size=2;
   }

   /* DMSP:  line_size=2400  sample_size=2400  pixel_size=1 */
   else if ((nn=strstr(input_filename, "I004")) != NULL) {
            printf("line size=641  sample size=441   pixel size=2\n");
       *line_size=*sample_size=2400;
       *pixel_size=1;
   }
   else if ((nn=strstr(input_filename, "I005")) != NULL) {
            printf("line size=641  sample size=441   pixel size=2\n");
       *line_size=*sample_size=2400;
       *pixel_size=1;
   }
   else if ((nn=strstr(input_filename, "I006")) != NULL) {
            printf("line size=641  sample size=441   pixel size=2\n");
       *line_size=*sample_size=2400;
       *pixel_size=1;
   }

   /* unknown: ask user */
   else {


            printf("Enter line size: ");
            if ((cc = gets(buf)) == NULL){
                printf(GETS_ERROR);
                exit(0);
            } /* end if cc */
            *line_size = atoi(buf);

            printf("Enter sample size: ");
            if ((cc = gets(buf)) == NULL){
                printf(GETS_ERROR);
                exit(0);
            } /* end if cc */
            *sample_size = atoi(buf);

            printf("Enter pixel size (number of 8-bit bytes): ");
            if ((cc = gets(buf)) == NULL){
                printf(GETS_ERROR);
                exit(0);
            } /* end if cc */
            *pixel_size = atoi(buf);
   }

   printf("line size=%d  sample size=%d   pixel size=%d\n",
           *line_size, *sample_size, *pixel_size);
   return (RC_GOOD);

} /* end figure_out() */

/************************************************************************
 *
 *   function tdf_channel() - asks user for desired channel number
 *
 ************************************************************************/
int
tdf_channel(channel_num)
int *channel_num;
{
  char *cc, n;

  do {
      printf("\nEnter channel number (1 to 5) or quit: ",
          &n);
      if ((cc = gets(buf)) == NULL){
          printf(GETS_ERROR);
          exit(0);
      } /* end if cc */
      if ((strncmp(buf,"quit",4)) == 0) return(RC_QUIT);
      if ((strncmp(buf,"QUIT",4)) == 0) return(RC_QUIT);

      n = atoi(buf);

  } while (n <= 0 && n > 5);
  *channel_num = n;
  return(RC_GOOD);
} /* end of tdf_channel() */



/******* month_name **************************************************
 * gets the month name 
 */
char
     *month_name(n)
     int n;
{
     static char *name[] ={
          "Bad", /* illegal month */
          "Jan",
          "Feb",
          "Mar",
          "Apr",
          "May",
          "Jun",
          "Jul",
          "Aug",
          "Sep",
          "Oct",
          "Nov",
          "Dec"
     }; /* end of static char */
     return((n < 1 || n > 12) ? name[0] : name[n]);
}/* end of month_name */

/************************************************************************
 *   END OF FILE tch_user.c
 ************************************************************************/
