/************************************************************************
 *
 *  tchannel.c 
 *  Terascan extraction  Main Program
 *  
 *  This program is an example of how to extract a channel's data
 *  array from a Terascan satellite image file.  This program uses
 *  tch_user.c.  This C module is part of the code used to generate
 *  tchannel.exe.
 *  
 *  ADM   29 MAR 1993
 *
 ************************************************************************/

/******* compiler #includes *******/
#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <malloc.h>

/******* program #includes *******/
#include "tch_defs.h"

/******* local global data *******/
char
    buf[BUF_SIZE],
    input_filename[FNAME_SIZE],
    output_filename[FNAME_SIZE];


  /*
   *
   */


/************************************************************************
 *
 *  main program 
 *
 ************************************************************************/
main()
{
  int
      channel_num,
      line_size,
      buf_size,
      pixel_size,
      sample_size,
      error_flag,
      i,j,k,
      n_written,
      n_read,
      in_fd,    /* input file descriptor */
      out_fd,   /* output file descriptor */
      rc;       /* return code */
  float
      x;
  long
      channel_offset;
  double
      xxx;
  char
      *mbuf;

  do {

      bzero(input_filename, sizeof(input_filename));
      bzero(buf, sizeof(buf));
      bzero(output_filename, sizeof(output_filename));
      /*************************************************
       *  ask user for name of terascan image file
       */
      do {
          rc = tdf_infilename(input_filename);
          if (strlen(input_filename) != 0) {
            if (rc == RC_QUIT) exit();
            if ((in_fd = open (input_filename,O_RDONLY,0)) == -1) {
              rc=RC_NOFILE;
              printf(FILE_NOT_FOUND,input_filename);
            }
            else close(in_fd);
          }
          else rc=RC_NOFILE;
      } while (rc == RC_NOFILE);

      /*************************************************
       *  figure out what kind of file it is
       */
      rc = figure_out(input_filename, &line_size, &sample_size,
                      &pixel_size);
      if (rc == RC_QUIT) exit();

      /*************************************************
       *  ask user to select a channel to extract
       */
      rc = tdf_channel(&channel_num);
      if (rc == RC_QUIT) exit();

      /*************************************************
       *  tell user what the output file name will be and
       *  give user the option to change the name of the output file
       */
      do {
          rc = tdf_outfilename(output_filename, channel_num);
          if (rc == RC_QUIT) exit();
          if ((out_fd=creat(output_filename, 0666)) == -1) {
              printf(COULD_NOT_CREATE,output_filename);
              rc = RC_NOCREAT;
          }
      } while (rc == RC_NOCREAT);


      if ((in_fd = open (input_filename,O_RDONLY,0)) == -1) {
          rc=RC_NOFILE;
          printf(FILE_NOT_FOUND,input_filename);
      }


      /*************************************************
       *  extract the array
       *     NE Corner:  57 deg 15.0 min E, 33 deg 30.0 min N
       *     SW Corner:  43 deg 45.0 min E, 21 deg 30.0 min N
       */
      channel_offset = 644 + ((channel_num - 1) *
          pixel_size * line_size * sample_size);
      lseek(in_fd, channel_offset, SEEK_SET);

      mbuf = (char *) malloc(line_size);
      if (mbuf == NULL) {
         mbuf = (char *) malloc(sample_size);
         if (mbuf == NULL) {
             printf("Error: not enough memory\n");
             exit();
         }
         else buf_size=sample_size;
      }
      else buf_size=line_size;

      k = ((double)(line_size) *
           (double)(sample_size) *
           (double)(pixel_size)) /
           (double)(buf_size);

      for (i = 0; i < k; i++) {
          n_read = read(in_fd, mbuf, buf_size);
          if (n_read == 0) {
              /* end of file */
              break;
          }
          else if (n_read == -1) {
              printf(READ_ERROR);
              /* error! */
              break;
          }
          else {
              /*
               *   WARNING:  This does not scale the data!!!
               */
              
              n_written = write(out_fd, mbuf, n_read);
              if (n_written != n_read) {
                  /* error! */
                  printf(WRITE_ERROR);
                  break;
              }
          }
      }

      /*************************************************
       * close the input and output files
       */
     free(mbuf);
     close(in_fd);
     close(out_fd);

  } while (TRUE);

} /* end main() */

 /************************************************************************
 *   END OF FILE tchannel.c
 ************************************************************************/
